afths: mcmc function

Description Usage Arguments Value

Description

MCMC routine for the strucatural equation model

Usage

1
afths(ct, X, nburnin = 1000, nmc = 5000, thin = 1, Xtest = NULL, cttest = NULL)

Arguments

ct

survival response, a n*2 matrix with first column as response and second column as right censored indicator, 1 is event time and 0 is right censored.

X

Matrix of covariates, dimension n*p.

nburnin

number of burin samples to discard

nmc

number of markov chain monte carlo samples after burnin

thin

thinning parameter. Default is 1 (no thinning)

Xtest

test design matrix

cttest

test survival response

Value

BetaHat

Posterior mean of β for survival model, a p by 1 vector

BetaMedian

Posterior median of beta for survival model, a p by 1 vector

Sigma2Hat

Posterior mean of error variance σ^2

AlphaHat

Posterior mean of α

BetaSamples

Posterior samples of β

Sigma2Samples

Posterior samples of σ^2

SurvivalHat

Predictive survival probability

LogTimeHat

Predictive log time

DIC

Deviance Information Criterion

WAIC

Widely Accepted Information Criterion

LambdaHat

Posterior mean of λ, p/2 by 1 vector


MAITYA02/circgene documentation built on April 25, 2021, 3:14 p.m.